.. _examples:

========
Examples
========

Tutorial Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    tut_hello_world
    tut_person
    tut_employee


Widgets Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    ex_buttons
    ex_context_menu
    ex_dates
    ex_dock_area
    ex_dock_pane
    ex_drag_and_drop
    ex_dual_slider
    ex_field
    ex_file_dialog
    ex_flow_area
    ex_focus_traversal
    ex_form_spacing
    ex_form
    ex_group_box
    ex_h_group
    ex_image_view
    ex_ipython_console
    ex_main_window
    ex_menu_bar
    ex_mdi_area
    ex_mpl_canvas
    ex_notebook
    ex_popup_menu
    ex_popup_view
    ex_progress_bar
    ex_scroll_area
    ex_slider
    ex_spin_box
    ex_splitter
    ex_tool_bar
    ex_tool_buttons
    ex_v_group
    ex_vtk_canvas
    ex_window
    ex_window_children


Layout Examples
-------------------------------------------------------------------------------

Basic
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. toctree::
    :maxdepth: 1

    ex_align
    ex_align_offset
    ex_grid
    ex_hbox
    ex_hbox_equal_widths
    ex_hbox_spacing
    ex_horizontal
    ex_linear_relations
    ex_vbox
    ex_vertical

Advanced
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. toctree::
    :maxdepth: 1

    ex_button_ring
    ex_factory_func
    ex_find_replace
    ex_fluid
    ex_manual_hbox
    ex_manual_vbox
    ex_nested_boxes
    ex_nested_containers
    ex_override_layout_constraints
    ex_centered_grid


Stdlib Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    ex_mapped_view
    ex_message_box
    ex_task_dialog


Dynamic Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    ex_conditional
    ex_fields
    ex_looper
    ex_notebook_pages


Aliases Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    ex_chained_attribute_alias
    ex_chained_widget_alias
    ex_simple_attribute_alias
    ex_simple_widget_alias


Functions Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    ex_declare_function
    ex_observe_model_signal
    ex_override_function


Styling Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    ex_banner
    ex_dock_item_alerts
    ex_gradient_push_button


Templates Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    ex_advanced
    ex_basic


Applib Examples
-------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    ex_live_editor


Workbench Examples
--------------------------------------------------------------------------------

.. toctree::
    :maxdepth: 1

    wb_sample
